import { getAuth } from "firebase-admin/auth";
import { createLogger, UnauthorisedError, userRequestStorageProvider } from "@mondokit/gcp-core";
const convertIdTokenToUser = async (idToken) => ({
    id: idToken.uid,
    email: idToken.email,
    roles: idToken.roles ?? [],
});
export const verifyFirebaseUser = (firebaseAdmin, options) => {
    const logger = createLogger("verifyFirebaseUser");
    const userConverter = options?.userConverter || convertIdTokenToUser;
    return async (req, res, next) => {
        const authHeader = req.headers.authorization;
        if (authHeader && authHeader.startsWith("Bearer ")) {
            try {
                logger.debug("Verifying Bearer token from Authorization header");
                const idToken = await getAuth().verifyIdToken(authHeader.substring(7));
                const user = await userConverter(idToken);
                logger.info(`Verified firebase token for user ${user.id} with roles ${user.roles}`);
                userRequestStorageProvider.get().set(user);
            }
            catch (e) {
                next(new UnauthorisedError(`Error verifying token: ${e.message}`));
            }
        }
        else {
            logger.debug("No Authorization header found");
        }
        next();
    };
};
//# sourceMappingURL=verify-firebase-user.js.map